@@ -37,8 +37,8 @@ KCMAkregatorAppearanceConfig::KCMAkregatorAppearanceConfig(QObject *parent, cons
     connect(m_ui.slider_minimumFontSize, &QAbstractSlider::sliderMoved, m_ui.kcfg_MinimumFontSize, &QSpinBox::setValue);
     connect(m_ui.slider_mediumFontSize, &QAbstractSlider::sliderMoved, m_ui.kcfg_MediumFontSize, &QSpinBox::setValue);
 
-    connect(m_ui.kcfg_MinimumFontSize, &KPluralHandlingSpinBox::valueChanged, m_ui.slider_minimumFontSize, &QSlider::setValue);
-    connect(m_ui.kcfg_MediumFontSize, &KPluralHandlingSpinBox::valueChanged, m_ui.slider_mediumFontSize, &QSlider::setValue);
+    connect(m_ui.kcfg_MinimumFontSize, &QSpinBox::valueChanged, m_ui.slider_minimumFontSize, &QSlider::setValue);
+    connect(m_ui.kcfg_MediumFontSize, &QSpinBox::valueChanged, m_ui.slider_mediumFontSize, &QSlider::setValue);
 
     m_ui.slider_minimumFontSize->setDisabled(Settings::self()->isImmutable(QStringLiteral("MinimumFontSize")));
     m_ui.slider_mediumFontSize->setDisabled(Settings::self()->isImmutable(QStringLiteral("MediumFontSize")));
