@@ -7,7 +7,6 @@
 
 #pragma once
 
-#include "kcmutils_version.h"
 #include "ui_settings_appearance.h"
 #include <KCModule>
 
@@ -19,11 +18,7 @@ class KCMAkregatorAppearanceConfig : public KCModule
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KCMAkregatorAppearanceConfig(QWidget *parent, const QVariantList &args);
-#else
-    explicit KCMAkregatorAppearanceConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-#endif
+    explicit KCMAkregatorAppearanceConfig(QObject *parent, const KPluginMetaData &data);
 
 private:
     QWidget *const m_widget;
