@@ -14,28 +14,25 @@
 
 using namespace Akregator;
 
-class Q_DECL_HIDDEN Command::Private
+class Akregator::CommandPrivate
 {
 public:
-    Private();
+    CommandPrivate();
     QPointer<QWidget> parentWidget;
 };
 
-Command::Private::Private()
+CommandPrivate::CommandPrivate()
     : parentWidget()
 {
 }
 
 Command::Command(QObject *parent)
     : QObject(parent)
-    , d(new Private)
+    , d(new CommandPrivate)
 {
 }
 
-Command::~Command()
-{
-    delete d;
-}
+Command::~Command() = default;
 
 QWidget *Command::parentWidget() const
 {
@@ -70,3 +67,5 @@ void Command::waitForFinished()
     connect(this, &Command::finished, &loop, &QEventLoop::quit);
     loop.exec();
 }
+
+#include "moc_command.cpp"
