@@ -64,10 +64,10 @@ public:
     /** converts strings to ArchiveMode value
         if parsing fails, it returns ArchiveMode::globalDefault
         */
-    static ArchiveMode stringToArchiveMode(const QString &str);
+    [[nodiscard]] static ArchiveMode stringToArchiveMode(const QString &str);
 
     /** converts ArchiveMode values to corresponding strings */
-    static QString archiveModeToString(ArchiveMode mode);
+    [[nodiscard]] static QString archiveModeToString(ArchiveMode mode);
 
     /** creates a Feed object from a description in OPML format */
     static Feed *fromOPML(const QDomElement &e, Akregator::Backend::Storage *storage);
@@ -171,7 +171,7 @@ public:
     /** returns whether a fetch error has occurred */
     [[nodiscard]] bool fetchErrorOccurred() const;
 
-    Syndication::ErrorCode fetchErrorCode() const;
+    [[nodiscard]] Syndication::ErrorCode fetchErrorCode() const;
 
     /** returns the unread count for this feed */
     [[nodiscard]] int unread() const override;
@@ -222,6 +222,11 @@ public:
     void setFaviconLocalPath(const QString &file);
     void setCopyright(const QString &copyright);
     [[nodiscard]] QString copyright() const;
+    [[nodiscard]] QStringList activities() const;
+    void setActivities(const QStringList &lst);
+
+    [[nodiscard]] bool activityEnabled() const;
+    void setActivityEnabled(bool b);
 public Q_SLOTS:
     /** starts fetching */
     void fetch(bool followDiscovery = false);
@@ -247,11 +252,9 @@ Q_SIGNALS:
 
 private:
     Akregator::Backend::Storage *storage();
-
-private:
     void setFavicon(const QIcon &icon);
     void loadFavicon(const QString &url, bool downloadFavicon);
-    QList<Article> articles() override;
+    [[nodiscard]] QList<Article> articles() override;
 
     /** loads articles from archive **/
     void loadArticles();
@@ -284,10 +287,10 @@ private:
     void appendArticle(const Article &a);
 
     /** checks whether article @c a is expired (considering custom and global archive mode settings) */
-    bool isExpired(const Article &a) const;
+    [[nodiscard]] bool isExpired(const Article &a) const;
 
     /** returns @c true if either this article uses @c limitArticleAge as custom setting or uses the global default, which is @c limitArticleAge */
-    bool usesExpiryByAge() const;
+    [[nodiscard]] bool usesExpiryByAge() const;
 
     /** executes the actual fetch action */
     void tryFetch();
@@ -302,3 +305,4 @@ private:
     std::unique_ptr<FeedPrivate> const d;
 };
 } // namespace Akregator
+Q_DECLARE_TYPEINFO(Akregator::Feed::ImageInfo, Q_RELOCATABLE_TYPE);
