@@ -44,7 +44,6 @@
 #include "types.h"
 #include "whatsnew/whatsnewtranslations.h"
 #include "widgets/searchbar.h"
-#include <PimCommon/WhatsNewMessageWidget>
 #include <WebEngineViewer/ZoomActionMenu>
 
 #include <KAboutData>
@@ -64,10 +63,18 @@
 #include <QVBoxLayout>
 
 #include "webengine/webengineframe.h"
+#include <PimCommon/NetworkManager>
+#if HAVE_TEXTUTILS_HAS_WHATSNEW_SUPPORT
+#include <TextAddonsWidgets/NeedUpdateVersionUtils>
+#include <TextAddonsWidgets/NeedUpdateVersionWidget>
+#include <TextAddonsWidgets/WhatsNewDialog>
+#include <TextAddonsWidgets/WhatsNewMessageWidget>
+#else
 #include <PimCommon/NeedUpdateVersionUtils>
 #include <PimCommon/NeedUpdateVersionWidget>
-#include <PimCommon/NetworkManager>
 #include <PimCommon/WhatsNewDialog>
+#include <PimCommon/WhatsNewMessageWidget>
+#endif
 #include <algorithm>
 #include <chrono>
 #include <memory>
@@ -110,6 +117,17 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
     auto topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins({});
     topLayout->setSpacing(0);
+#if HAVE_TEXTUTILS_HAS_WHATSNEW_SUPPORT
+    if (TextAddonsWidgets::NeedUpdateVersionUtils::checkVersion()) {
+        const auto status =
+            TextAddonsWidgets::NeedUpdateVersionUtils::obsoleteVersionStatus(QLatin1String(AKREGATOR_RELEASE_VERSION_DATE), QDate::currentDate());
+        if (status != TextAddonsWidgets::NeedUpdateVersionUtils::ObsoleteVersion::NotObsoleteYet) {
+            auto needUpdateVersionWidget = new TextAddonsWidgets::NeedUpdateVersionWidget(this);
+            topLayout->addWidget(needUpdateVersionWidget);
+            needUpdateVersionWidget->setObsoleteVersion(status);
+        }
+    }
+#else
     if (PimCommon::NeedUpdateVersionUtils::checkVersion()) {
         const auto status = PimCommon::NeedUpdateVersionUtils::obsoleteVersionStatus(QLatin1String(AKREGATOR_RELEASE_VERSION_DATE), QDate::currentDate());
         if (status != PimCommon::NeedUpdateVersionUtils::ObsoleteVersion::NotObsoleteYet) {
@@ -118,6 +136,7 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
             needUpdateVersionWidget->setObsoleteVersion(status);
         }
     }
+#endif
 
     WhatsNewTranslations translations;
     const QString newFeaturesMD5 = translations.newFeaturesMD5();
@@ -126,8 +145,13 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
         if (!previousNewFeaturesMD5.isEmpty()) {
             const bool hasNewFeature = (previousNewFeaturesMD5 != newFeaturesMD5);
             if (hasNewFeature) {
+#if HAVE_TEXTUTILS_HAS_WHATSNEW_SUPPORT
+                auto whatsNewMessageWidget = new TextAddonsWidgets::WhatsNewMessageWidget(this, i18n("Akregator"));
+                whatsNewMessageWidget->setWhatsNewInfos(translations.createWhatsNewInfo());
+#else
                 auto whatsNewMessageWidget = new PimCommon::WhatsNewMessageWidget(this, i18n("Akregator"));
                 whatsNewMessageWidget->setWhatsNewInfos(translations.createWhatsNewInfo());
+#endif
                 whatsNewMessageWidget->setObjectName(QStringLiteral("whatsNewMessageWidget"));
                 topLayout->addWidget(whatsNewMessageWidget);
                 Settings::self()->setPreviousNewFeaturesMD5(newFeaturesMD5);
@@ -1068,9 +1092,8 @@ void MainWidget::slotCopyLinkAddress()
         return;
     }
 
-    QString link;
     if (article.link().isValid()) {
-        link = article.link().url();
+        const QString link = article.link().url();
         QClipboard *cb = QApplication::clipboard();
         cb->setText(link, QClipboard::Clipboard);
         // don't set url to selection as it's a no-no according to a fd.o spec
@@ -1252,7 +1275,7 @@ void MainWidget::readProperties(const KConfigGroup &config)
     int currentFrameId = -1;
     for (const QString &framePrefix : childList) {
         auto const frame = new WebEngineFrame(m_actionManager->actionCollection(), m_tabWidget);
-        frame->loadConfig(config, framePrefix + QLatin1Char('_'));
+        frame->loadConfig(config, framePrefix + u'_');
 
         connectFrame(frame);
         Kernel::self()->frameManager()->slotAddFrame(frame);
@@ -1328,7 +1351,11 @@ void MainWidget::slotFocusQuickSearch()
 void MainWidget::slotWhatsNew()
 {
     WhatsNewTranslations translations;
+#if HAVE_TEXTUTILS_HAS_WHATSNEW_SUPPORT
+    TextAddonsWidgets::WhatsNewDialog dlg(translations.createWhatsNewInfo(), this, i18n("Akregator"));
+#else
     PimCommon::WhatsNewDialog dlg(translations.createWhatsNewInfo(), this, i18n("Akregator"));
+#endif
     dlg.updateInformations();
     dlg.exec();
 }
